# ChemDoE

This instrument is to be integrated into the software ecosystem of the ELN [Chemotion](https://chemotion.net/). It is a graphical user interface (GUI) client that facilitates the utilization of design of experiment algorithms to populate the variations of a reaction in Chemotion.

Full Docu: [ChemDoE on Read the Docs](https://chemdoe.readthedocs.io/en/latest/index.html)
